Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(238)

Unified Diff: pkg/compiler/lib/src/types/type_mask.dart

Issue 1342933006: Rename ReceiverMask and ReceiverMaskSet and update comments. (Closed) Base URL: https://github.com/dart-lang/sdk.git@master
Patch Set: Fix after rebase Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/compiler/lib/src/types/type_mask.dart
diff --git a/pkg/compiler/lib/src/types/type_mask.dart b/pkg/compiler/lib/src/types/type_mask.dart
index 65cf5969b9de21349f44b598076923f8cd8589e4..7cbecc501ecdd4c72d7ca46a4242dc07a9be3f43 100644
--- a/pkg/compiler/lib/src/types/type_mask.dart
+++ b/pkg/compiler/lib/src/types/type_mask.dart
@@ -4,10 +4,10 @@
part of types;
/// An implementation of a [UniverseReceiverMaskSet] that is consists if an only
/// increasing set of [TypeMask]s, that is, once a mask is added it cannot be
/// removed.
-class IncreasingTypeMaskSet extends UniverseReceiverMaskSet {
+class IncreasingTypeMaskSet extends UniverseSelectorConstraints {
bool isAll = false;
Set<TypeMask> _masks;
@@ -37,7 +37,7 @@ class IncreasingTypeMaskSet extends UniverseReceiverMaskSet {
}
@override
- bool addReceiverMask(TypeMask mask) {
+ bool addReceiverConstraint(TypeMask mask) {
if (isAll) return false;
if (mask == null) {
isAll = true;
@@ -61,11 +61,11 @@ class IncreasingTypeMaskSet extends UniverseReceiverMaskSet {
}
}
-class TypeMaskStrategy implements ReceiverMaskStrategy {
+class TypeMaskStrategy implements SelectorConstraintsStrategy {
const TypeMaskStrategy();
@override
- UniverseReceiverMaskSet createReceiverMaskSet(Selector selector) {
+ UniverseSelectorConstraints createSelectorConstraints(Selector selector) {
return new IncreasingTypeMaskSet();
}
}
@@ -75,7 +75,7 @@ class TypeMaskStrategy implements ReceiverMaskStrategy {
* operations on it are not guaranteed to be precise and they may
* yield conservative answers that contain too many classes.
*/
-abstract class TypeMask implements ReceiverMask {
+abstract class TypeMask implements ReceiverConstraint {
factory TypeMask(ClassElement base,
int kind,
bool isNullable,
@@ -4,10 +4,10 @@
part of types;
-/// An implementation of a [UniverseReceiverMaskSet] that is consists if an only
+/// An implementation of a [UniverseSelectorConstraints] that is consists if an only
/// increasing set of [TypeMask]s, that is, once a mask is added it cannot be
/// removed.
« no previous file with comments | « pkg/compiler/lib/src/js_emitter/program_builder/program_builder.dart ('k') | pkg/compiler/lib/src/types/types.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698